searchData={"items":[{"type":"module","title":"NLdoc.Validation","doc":"NLdoc Validation is a library that provides accessibility validation for NLdoc documents.\nTODO: proper description","ref":"NLdoc.Validation.html"},{"type":"function","title":"NLdoc.Validation.validate/1","doc":"","ref":"NLdoc.Validation.html#validate/1"},{"type":"function","title":"NLdoc.Validation.validate/2","doc":"","ref":"NLdoc.Validation.html#validate/2"},{"type":"module","title":"NLdoc.Validation.Content","doc":"This module provides helper functions for validating the content of NLdoc spec objects.","ref":"NLdoc.Validation.Content.html"},{"type":"function","title":"NLdoc.Validation.Content.visible_text?/1","doc":"Returns true if the given text is visible, i.e. consists anything else than whitespace or invisible characters.\nIf the given text is an `NLdoc.Spec` object, this function will recursively check whether any of its children\ncontain visible text.","ref":"NLdoc.Validation.Content.html#visible_text?/1"},{"type":"behaviour","title":"NLdoc.Validation.Rule","doc":"This module provides a macro for defining validation rules for NLdoc spec objects, i.e. documents and their elements.\nSuch rules check for semantic correctness and accessibility concerns in the spec objects.\n\nSimply `use NLdoc.Validation.Rule` in your module with all details about the validation rule and implement the `valid?/1`\nfunction to determine whether the spec objects that this rule validates, are valid.\n\nYou may also choose to override the `validates/0` and `make_validation/1` functions for more granular control over the\nvalidation process.\n\nIf your validation rule requires state to be maintained during the validation process, implement an `update_state/2` function\nto update the `NLdoc.Validation.State` struct with the necessary information.\n\nNote that the application of and merging of autofixes to a document as a result of validation is currently not implemented.\n\nExample:\n\n    defmodule NLdoc.Validation.Rules.HeadingLevelValid do\n      use NLdoc.Validation.Rule,\n        severity: NLdoc.Validation.Severity.error(),\n        rule: \"invalid-heading-level\",\n        ruleset: \"https://html.spec.whatwg.org/\",\n        ruleset_version: \"5\",\n        validates: [NLdoc.Spec.Heading]\n\n      @impl true\n      def valid?(%NLdoc.Spec.Heading{level: level}, _),\n        do: level >= 1 and level <= 6\n    end","ref":"NLdoc.Validation.Rule.html"},{"type":"callback","title":"NLdoc.Validation.Rule.make_validation/1","doc":"","ref":"NLdoc.Validation.Rule.html#c:make_validation/1"},{"type":"type","title":"NLdoc.Validation.Rule.opt/0","doc":"","ref":"NLdoc.Validation.Rule.html#t:opt/0"},{"type":"type","title":"NLdoc.Validation.Rule.t/0","doc":"","ref":"NLdoc.Validation.Rule.html#t:t/0"},{"type":"callback","title":"NLdoc.Validation.Rule.update_state/2","doc":"","ref":"NLdoc.Validation.Rule.html#c:update_state/2"},{"type":"callback","title":"NLdoc.Validation.Rule.valid?/2","doc":"","ref":"NLdoc.Validation.Rule.html#c:valid?/2"},{"type":"callback","title":"NLdoc.Validation.Rule.validate/2","doc":"","ref":"NLdoc.Validation.Rule.html#c:validate/2"},{"type":"callback","title":"NLdoc.Validation.Rule.validates/0","doc":"","ref":"NLdoc.Validation.Rule.html#c:validates/0"},{"type":"module","title":"NLdoc.Validation.Rules.DefinitionListHasDefinitionTerm","doc":"This rule validates that the a definition list has at least one definition term.","ref":"NLdoc.Validation.Rules.DefinitionListHasDefinitionTerm.html"},{"type":"function","title":"NLdoc.Validation.Rules.DefinitionListHasDefinitionTerm.has_definition_term?/1","doc":"","ref":"NLdoc.Validation.Rules.DefinitionListHasDefinitionTerm.html#has_definition_term?/1"},{"type":"module","title":"NLdoc.Validation.Rules.DefinitionTermHasDefinitionDetails","doc":"This rule validates that each DefinitionTerm in a DefinitionList is followed by a DefinitionDetails.","ref":"NLdoc.Validation.Rules.DefinitionTermHasDefinitionDetails.html"},{"type":"module","title":"NLdoc.Validation.Rules.EmptyDefinitionDetails","doc":"This rule validates that definition details must always contain visible text.","ref":"NLdoc.Validation.Rules.EmptyDefinitionDetails.html"},{"type":"module","title":"NLdoc.Validation.Rules.EmptyDefinitionTerm","doc":"This rule validates that a definition term must always contain visible text.","ref":"NLdoc.Validation.Rules.EmptyDefinitionTerm.html"},{"type":"module","title":"NLdoc.Validation.Rules.EmptyHeading","doc":"This rule validates that a heading must always contain visible text.","ref":"NLdoc.Validation.Rules.EmptyHeading.html"},{"type":"module","title":"NLdoc.Validation.Rules.EmptyTableHeader","doc":"This rule validates that a table header must always contain visible text.","ref":"NLdoc.Validation.Rules.EmptyTableHeader.html"},{"type":"module","title":"NLdoc.Validation.Rules.HeadingLevelValid","doc":"This rule validates that a heading's level is valid according to the HTML spec (i.e. between 1 and 6).","ref":"NLdoc.Validation.Rules.HeadingLevelValid.html"},{"type":"module","title":"NLdoc.Validation.Rules.HeadingOrder","doc":"This rule validates that headings are ordered sequentially-descending,\ni.e. heading levels should only increase by one, but may decrease by any.","ref":"NLdoc.Validation.Rules.HeadingOrder.html"},{"type":"module","title":"NLdoc.Validation.Rules.ImageMustHaveAlt","doc":"This rule validates that an image has an alternative text, or is marked as decorative.","ref":"NLdoc.Validation.Rules.ImageMustHaveAlt.html"},{"type":"module","title":"NLdoc.Validation.Rules.LinkName","doc":"This rule validates that a link must always contain visible text.","ref":"NLdoc.Validation.Rules.LinkName.html"},{"type":"module","title":"NLdoc.Validation.Rules.NoUnderline","doc":"This rule validates that the style underline was not used on a Text.","ref":"NLdoc.Validation.Rules.NoUnderline.html"},{"type":"module","title":"NLdoc.Validation.Rules.PageHasHeadingOne","doc":"This rule validates that a document has at least one heading level 1.","ref":"NLdoc.Validation.Rules.PageHasHeadingOne.html"},{"type":"module","title":"NLdoc.Validation.Rules.PageHasMultipleHeadingOne","doc":"This rule validates that the document has only one Heading with level 1.","ref":"NLdoc.Validation.Rules.PageHasMultipleHeadingOne.html"},{"type":"module","title":"NLdoc.Validation.Rules.PageStartsWithHeadingOne","doc":"This rule validates that a document starts with a Heading with level 1.\nIt produces a validation finding on the first heading with level 1 found in the document,\nif it is not the first element in the document.\n\nNote: this rule will *not* produce a validation finding if the document does not contain a heading with level 1.","ref":"NLdoc.Validation.Rules.PageStartsWithHeadingOne.html"},{"type":"module","title":"NLdoc.Validation.Rules.TableNeedsMultipleRows","doc":"This rule validates that tables have more than one row.","ref":"NLdoc.Validation.Rules.TableNeedsMultipleRows.html"},{"type":"module","title":"NLdoc.Validation.Severity","doc":"Severity levels for validation rules.","ref":"NLdoc.Validation.Severity.html"},{"type":"function","title":"NLdoc.Validation.Severity.error/0","doc":"","ref":"NLdoc.Validation.Severity.html#error/0"},{"type":"function","title":"NLdoc.Validation.Severity.notice/0","doc":"","ref":"NLdoc.Validation.Severity.html#notice/0"},{"type":"type","title":"NLdoc.Validation.Severity.t/0","doc":"","ref":"NLdoc.Validation.Severity.html#t:t/0"},{"type":"function","title":"NLdoc.Validation.Severity.values/0","doc":"","ref":"NLdoc.Validation.Severity.html#values/0"},{"type":"function","title":"NLdoc.Validation.Severity.warning/0","doc":"","ref":"NLdoc.Validation.Severity.html#warning/0"},{"type":"module","title":"NLdoc.Validation.State","doc":"State for validation rules.","ref":"NLdoc.Validation.State.html"},{"type":"function","title":"NLdoc.Validation.State.get/2","doc":"Gets the given field from the state object.\n\nThis function only accepts fields of the state, which are :findings, :heading_level, :definition_term_id_without_details, :encountered_heading_1?.\nIt will raise if the field is not valid.","ref":"NLdoc.Validation.State.html#get/2"},{"type":"function","title":"NLdoc.Validation.State.keep/3","doc":"Modifies a state object by setting the given field to the value that field had in the old state.\n\nThis function only accepts fields of the state, which are :findings, :heading_level, :definition_term_id_without_details, :encountered_heading_1?.\nIt will raise if the field is not valid.","ref":"NLdoc.Validation.State.html#keep/3"},{"type":"function","title":"NLdoc.Validation.State.prepend/3","doc":"Prepends a list of values or a single value to the list field in the state object.\n\nThis function only accepts fields of the state, which are :findings.\nIt will raise if the field is not valid.","ref":"NLdoc.Validation.State.html#prepend/3"},{"type":"function","title":"NLdoc.Validation.State.set/3","doc":"Sets the given field on the state object to the given value.\n\nThis function only accepts fields of the state, which are :findings, :heading_level, :definition_term_id_without_details, :encountered_heading_1?.\nIt will raise if the field is not valid.","ref":"NLdoc.Validation.State.html#set/3"},{"type":"type","title":"NLdoc.Validation.State.t/0","doc":"","ref":"NLdoc.Validation.State.html#t:t/0"},{"type":"extras","title":"NLdoc.Validation","doc":"# NLdoc.Validation","ref":"readme.html"},{"type":"extras","title":"Installation - NLdoc.Validation","doc":"The package can be installed by adding `nldoc_validation` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:nldoc_validation, \"~> 1.0.0\"}\n  ]\nend\n```\n\nDocumentation can be found at  .","ref":"readme.html#installation"},{"type":"extras","title":"1.0.0 (2025-01-23)","doc":"# 1.0.0 (2025-01-23)","ref":"changelog.html"},{"type":"extras","title":"Features - 1.0.0 (2025-01-23)","doc":"* **NLD-586:** NLdoc.Validation initial commit ([8b34338](https://gitlab.com/toegang-voor-iedereen/backend/lib/nldoc_validation/commit/8b34338c9e8aa5ca0084849e9984ad033e244656))\n\n# 1.0.0 (2025-01-23)","ref":"changelog.html#features"},{"type":"extras","title":"Bug Fixes - 1.0.0 (2025-01-23)","doc":"* **NLD-586:** package name ([5154b11](https://gitlab.com/toegang-voor-iedereen/backend/lib/nldoc_logging/commit/5154b1140e4f2b2fd3d204025efed0459bae7aed))","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Features - 1.0.0 (2025-01-23)","doc":"* **NLD-586:** package logger ([708895d](https://gitlab.com/toegang-voor-iedereen/backend/lib/nldoc_logging/commit/708895da7ca240dbde4b88420a0e40d14f55394e))","ref":"changelog.html#features"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}